## Copies files around, ready for a release.
##
## Authors: Kristoffer Lawson, setok@fishpool.com
##
## $Header$


if {[llength $argv] != 2} {
    puts stderr "Usage: $argv0 <destination> <version>"
    exit
}


set DestDir [lindex $argv 0]
set Version [lindex $argv 1]


# List of two--element lists.
# List syntax: 
# {pattern of files to copy} {sub-dir in $DestDir to copy to}

set FilePatterns(smake) {
    {*.tcl .}
    {*.txt .}
    {doc/* doc}
    {test/* test}
    {/home/setok/cvs/codebase/tcl/debug.tcl codebase}
}


# Do actual work

foreach component [array names FilePatterns] {
    file mkdir [file join $DestDir $component]
    foreach patternTuple $FilePatterns($component) {
	set pattern [lindex $patternTuple 0]
	set subDir [lindex $patternTuple 1]
	file mkdir [file join $DestDir $component $subDir]
	foreach file [glob $pattern] {
	    # Ignore sub-directories.		
	    if {! [file isdirectory $file]} {
		file copy -force $file [file join $DestDir $component $subDir \
					    [file tail $file]]
	    }
	}
    }

    # Post-processing    
    pkg_mkIndex [file join $DestDir $component codebase] *.tcl
    catch {
	exec lyx -e html [file join $DestDir $component doc smake.lyx]
	exec lyx -e linuxdoc [file join $DestDir $component doc smake.lyx]
    }
    set pwd [pwd]
#    cd [file join $DestDir $component doc]
#    exec linuxdoc -B txt -m smake.sgml
#    cd $pwd
    cd $DestDir
    exec tar zcvf ${component}-$Version.tar.gz $component
    cd $pwd
}


